function phantomObject = analysisOfFrames(phantomPosition)
% Performs: Search in the 5 frames

load param.mat;

phantomObject(1:length(info.names)) = struct('beam', 1, 'sample', 1, 'meanInt', 0, 'posX', 0, 'posY', 0, 'radRes', 0, 'latRes', 0, 'radResmm', 0, 'latResmm', 0,...
    'contrastRes_speckle', 0, 'contrastRes_pointTarget', 0, 'foundTot', false, 'values1', [], 'values2', [], 'values3', [], 'profile1', [], 'profile2', [], 'type', ' ');

for n = 1:length(info.names)
    
    point.beams     = zeros(1,4);
    point.samples   = zeros(1,4);
    if nargin < 1, 
        phantomPosition = GetPolygon(info.names(n));
    end
    
    for m = 1:4
        % OK when using tissue beams and samples
        [point_BS.samples, point_BS.beams]  = toBeamSpace(phantomPosition(m,1), phantomPosition(m,2),info);        
        
        point.beams(m)                      = point_BS.beams;
        point.samples(m)                    = point_BS.samples;
    end
            
    StartPt_BS.beams	= minValue(point.beams(1),   point.beams(2),   point.beams(3),   point.beams(4));
    StartPt_BS.samples  = minValue(point.samples(1), point.samples(2), point.samples(3), point.samples(4));
    EndPt_BS.beams      = maxValue(point.beams(1),   point.beams(2),   point.beams(3),   point.beams(4));
    EndPt_BS.samples	= maxValue(point.samples(1), point.samples(2), point.samples(3), point.samples(4));

    % Check for uncorrect beams and samples
    if (StartPt_BS.beams <= 0)
        StartPt_BS.beams = 1;
    end
    if (StartPt_BS.samples <= 0)
        StartPt_BS.samples = 1;
    end
    if (EndPt_BS.beams > info.gridSize(2) - 1)
        EndPt_BS.beams = info.gridSize(2)- 1;
    end
    if (EndPt_BS.samples > info.gridSize(1) - 1)
        EndPt_BS.samples = info.gridSize(1) - 1;
    end
   
    % profile and defining phantom
    phantomObject(n) = pointTargetCharacteristics(phantomObject(n), StartPt_BS, EndPt_BS);
    
    % Register the phantom object in the phantom object vector
    if ( (~alreadyFound(phantomObject, phantomObject(n), n)) && (overTheThreshold(phantomObject(n).beam, phantomObject(n).sample)) )
        phantomObject(n).foundTot = true;
    end
 
end
