function phantomObject = analysisOfGivenPhantomObjects(phantomObject, phantomObjectType, phantomObjectX, phantomObjectY)

info = struct();

load param.mat;
currentSize = length(phantomObject);

for i=1:size(phantomObjectType)
        if (phantomObjectType(i) == 0)
            phantomObject(currentSize+i).type = 'POINT_TARGET';
        elseif (phantomObjectType(i) == 1)
            phantomObject(currentSize+i).type = 'CYST';
        else
            phantomObject(currentSize+i).type = 'SPECKLE';
        end
        phantomObject(currentSize+i).posX = phantomObjectX(i);
        phantomObject(currentSize+i).posY = phantomObjectY(i);
end

% Analyse the phantom objects that were found
for a = currentSize+1:length(phantomObject)

    x = phantomObject(a).posX;
    y = phantomObject(a).posY;

    if (strcmp(phantomObject(a).type, 'CYST'))
        frameSize = 0.007;
    else
        frameSize = 0.005;
    end
        
    point.beams     = zeros(1,4);
    point.samples   = zeros(1,4);
    
    for m = 1:4
        if m == 1
            [point_BS.samples, point_BS.beams] = toBeamSpace(x-frameSize, y-frameSize, info);
        elseif m == 2
            [point_BS.samples, point_BS.beams] = toBeamSpace(x-frameSize, y+frameSize, info);
        elseif m == 3
            [point_BS.samples, point_BS.beams] = toBeamSpace(x+frameSize, y+frameSize, info);
        else
            [point_BS.samples, point_BS.beams] = toBeamSpace(x+frameSize, y-frameSize, info);
        end
        
        % Check for uncorrect beams and samples
        if (round(point_BS.beams) <= 0)
            point_BS.beams = 1;
        end
        if (round(point_BS.samples) <= 0)
            point_BS.samples = 1;
        end
        if (round(point_BS.beams) > info.gridSize(2))
            point_BS.beams = info.gridSize(2) - 1;
        end
        if (round(point_BS.samples) > info.gridSize(1))
            point_BS.samples = info.gridSize(1) - 1;
        end
        
        point.beams(m)      = point_BS.beams;
        point.samples(m)    = point_BS.samples;
    end
            
    StartPt_BS.beams	= minValue(point.beams(1),   point.beams(2),   point.beams(3),   point.beams(4));
    StartPt_BS.samples  = minValue(point.samples(1), point.samples(2), point.samples(3), point.samples(4));
    EndPt_BS.beams      = maxValue(point.beams(1),   point.beams(2),   point.beams(3),   point.beams(4));
    EndPt_BS.samples	= maxValue(point.samples(1), point.samples(2), point.samples(3), point.samples(4));

    % Check for uncorrect beams and samples
    if (StartPt_BS.beams <= 0)
        StartPt_BS.beams = 1;
    end
    if (StartPt_BS.samples <= 0)
        StartPt_BS.samples = 1;
    end
    if (EndPt_BS.beams > info.gridSize(2))
        EndPt_BS.beams = info.gridSize(2) - 1;
    end
    if (EndPt_BS.samples > info.gridSize(1))
        EndPt_BS.samples = info.gridSize(1) - 1;
    end


        %		POINT TARGETS
        % -----------------------

    if (strcmp(phantomObject(a).type,'POINT_TARGET'))

        % profile and defining phantom
       phantomObject(a) = pointTargetCharacteristics(phantomObject(a), StartPt_BS, EndPt_BS);

        if ( (~alreadyFound(phantomObject, phantomObject(a),a)) && (overTheThreshold(phantomObject(a).beam, phantomObject(a).sample)) )
            phantomObject(a).foundTot = true;
        else
            phantomObject(a).foundTot = false;
        end
    end

        %			CYSTS
        % -----------------------

    if (strcmp(phantomObject(a).type, 'CYST'))
        found	= false;

        % Parameter that must be chosen
        limit	= 25;

        b	= round(StartPt_BS.beams);
        s	= round(StartPt_BS.samples);

        % start point inside cyst
        if (data(s,b) < limit)
            % must be sure to search from the first point
            firstBlack          = false;
            firstPt_BS.samples  = s;
            firstPt_BS.beams    = b;

            while(~firstBlack && firstPt_BS.beams > 1)
                if ( data(firstPt_BS.samples,firstPt_BS.beams-1) < limit )
                    firstPt_BS.beams = firstPt_BS.beams - 1;
                else
                    firstBlack = true;
                end
            end
            if (firstBlack)
                phantomObject(a) = cystCharacteristics(phantomObject, phantomObject(a), firstPt_BS, limit);
                found = true;
            end
        % start point not inside cyst
        else
            while (b < round(EndPt_BS.beams) || s < round(EndPt_BS.samples) )
                if( data(s,b) < limit)
                    firstPt_BS.samples  = s;
                    firstPt_BS.beams    = b;
                    phantomObject(a)    = cystCharacteristics(phantomObject, phantomObject(a), firstPt_BS, limit);
                    % check that the region is big enough to be a dark cyst
                    if ( (phantomObject(a).radRes > 2) && (phantomObject(a).latRes > 1) )	% must have at least 2 samples and 1 beam
                        found = true;
                        break;
                    else						% false alarm, not a dark cyst and continue searching 
                        if (b < EndPt_BS.beams)
                            b = b + 1;
                        else
                            s = s + 1;
                            b = round(StartPt_BS.beams);
                        end
                    end
                else
                    if (b < EndPt_BS.beams)
                        b = b + 1;
                    else
                        s = s + 1;
                        b = round(StartPt_BS.beams);
                    end
                end
            end
        end

        if ( (~found) || (alreadyFound(phantomObject, phantomObject(a), a)) )
            phantomObject(a).foundTot = false;
        else
            phantomObject(a).foundTot = true;
        end
        
    end

    if (strcmp(phantomObject(a).type, 'SPECKLE')) 				% SPECKLE
        phantomObject(a).foundTot = false;
        % can be further developed
    end
end

% Display image
figure();
pcolor(info.x_scan*100,info.y_scan*100,data');
shading interp; colormap(gray(256));
axis equal; axis ij;
xlabel('Azimuth [cm]');ylabel('Depth [cm]');
set(gca,'Color',[0 0 0])
axis([-10 10 0 16]);
hold on;
for p = 1:length(phantomObject)    
    if (phantomObject(p).foundTot)
        if (p <= currentSize)
            col     = 'r';
            colPos  = 'ro';
        else
            col     = 'b';
            colPos  = 'bo';
        end

        x = phantomObject(p).posX;
        y = phantomObject(p).posY;
        plot(x*100,y*100,colPos);hold on;

        if (strcmp(phantomObject(p).type, 'CYST'))
            frameSize = 1.5;
        else
            frameSize = 1;
        end
        rectangle('Position', [x*100-(frameSize/2) y*100-(frameSize/2) frameSize frameSize], 'EdgeColor', col, 'LineWidth', 1.5);
    end
end