function out = calcDistSV(p, info, sv, data, f, n)
% calculating the distance

if f == 1
    point.beams     = zeros(1,4);
    point.samples   = zeros(1,4);

    phantomPosition = GetPolygon(info.namesMean(n));

    phantomPosition(1:2,1) = phantomPosition(1,1) - 0.01;
    phantomPosition(3:4,1) = phantomPosition(3,1) + 0.01;

    for m = 1:4       
        % OK when using tissue beams and samples
        [point_BS.samples, point_BS.beams]  = toBeamSpace(phantomPosition(m,1), phantomPosition(m,2),info);
        point.beams(m)                      = point_BS.beams;
        point.samples(m)                    = point_BS.samples;
    end

    StartPt_BS.beams	= minValue(point.beams(1),   point.beams(2),   point.beams(3),   point.beams(4));
    StartPt_BS.samples  = minValue(point.samples(1), point.samples(2), point.samples(3), point.samples(4));
    EndPt_BS.beams      = maxValue(point.beams(1),   point.beams(2),   point.beams(3),   point.beams(4));
    EndPt_BS.samples	= maxValue(point.samples(1), point.samples(2), point.samples(3), point.samples(4));

    % Check for uncorrect beams and samples
    if (StartPt_BS.beams <= 0)
        StartPt_BS.beams = 1;
    end
    if (StartPt_BS.samples <= 0)
        StartPt_BS.samples = 1;
    end
    if (EndPt_BS.beams > info.gridSize(2) - 1)
        EndPt_BS.beams = info.gridSize(2)- 1;
    end
    if (EndPt_BS.samples > info.gridSize(1) - 1)
        EndPt_BS.samples = info.gridSize(1) - 1;
    end

    ROI2        = data(StartPt_BS.samples:EndPt_BS.samples,StartPt_BS.beams:EndPt_BS.beams);
    [maxS,maxB] = find(ROI2 == max(max(ROI2)));

    centerB = StartPt_BS.beams + maxB(1) - 1;
    centerS = StartPt_BS.samples + maxS(1) - 1;
    startB  = centerB - round(p.sizeB/2);
    startS  = centerS - round(p.sizeS/2);
    endB    = centerB + ceil(p.sizeB/2) - 1;
    endS    = centerS + ceil(p.sizeS/2) - 1;

    if (startB <= 0)
        endB    = endB + abs(startB) + 1;
        startB  = 1;
    end
    if (startS <= 0)
        endS    = endS + abs(endS) + 1;
        startS  = 1;
    end
    if (endB > info.gridSize(2) - 1)
        startB  = startB - (endB-info.gridSize(2)-1);
        endB    = info.gridSize(2)- 1;
    end
    if (endS > info.gridSize(1) - 1)
        startS  = startS - (endS-info.gridSize(1)-1);
        endS    = info.gridSize(1) - 1;
    end
else
    centerB = sv(f-1).compare(n).centerB;
    centerS = sv(f-1).compare(n).centerS;
    startB  = centerB - round(p.sizeB/2);
    startS  = centerS - round(p.sizeS/2);
    endB    = centerB + ceil(p.sizeB/2) - 1;
    endS    = centerS + ceil(p.sizeS/2) - 1;

    if (startB <= 0)
        endB    = endB + abs(startB) + 1;
        startB  = 1;
    end
    if (startS <= 0)
        endS    = endS + abs(endS) + 1;
        startS  = 1;
    end
    if (endB > info.gridSize(2) - 1)
        startB  = startB - (endB-info.gridSize(2)-1);
        endB    = info.gridSize(2)- 1;
    end
    if (endS > info.gridSize(1) - 1)
        startS  = startS - (endS-info.gridSize(1)-1);
        endS    = info.gridSize(1) - 1;
    end
end

ROI2        = data(startS:endS,startB:endB);
[maxS,maxB] = find(ROI2 == max(max(ROI2)));

out.centerB = startB + maxB(1) - 1;
out.centerS = startS + maxS(1) - 1;

% Lateral
[x1,y1]     = fromBeamSpace(startS + maxS(1) - 1,startB, info);
[x2,y2]     = fromBeamSpace(startS + maxS(1) - 1,endB, info);
xShort      = linspace(x1,x2,size(ROI2,2));
xLong       = linspace(x1,x2,40*size(ROI2,2));

temp_lat    = ROI2((maxS(1)-1):(maxS(1)+1),:);
temp_lat    = mean(temp_lat);
lat         = interp1(xShort,temp_lat,xLong,'spline');

% Lateral
[lat_value,lat_index] = max(lat);
if p.N_MLA == 1
    threshold   = lat_value*10^(-1/10);              % -1dB below max-value
else
    threshold   = lat_value*10^(-1.5/10);
end
start_index = find(lat(1:lat_index) < threshold);
if(isempty(start_index))
    start_index = 1;
else
    start_index = start_index(end) - 10;
    if (start_index < 1)
        start_index = 1;
    end
end
end_index       = find(lat(lat_index:end) < threshold);
if(isempty(end_index))
    end_index   = length(lat);
else
    end_index   = end_index(1) + lat_index - 1 + 10;
    if (end_index > length(lat))
        end_index = length(lat);
    end
end

lat2        = lat(start_index:end_index);
xLong2      = xLong(start_index:end_index);

fg          = fittype('gauss1');
lat_gauss   = fit(xLong2',lat2',fg);
lat3        = lat_gauss(xLong2)';

% Better calculations
if (lat3(1) > lat3(end))
    [value, pos] = min(abs(lat3(3:end) - lat3(1)));
    out.x        = sum(xLong2(1:pos+2).*lat3(1:pos+2))/sum(lat3(1:pos+2));
else
    [value, pos] = min(abs(lat3(1:end-2) - lat3(end)));
    out.x        = sum(xLong2(pos:end).*lat3(pos:end))/sum(lat3(pos:end));
end

[x_notUsed,y] = fromBeamSpace(startS + maxS(1) - 1,startB + maxB(1) - 1, info);
% y dont need to be that exact
out.y = y; 
