function dumpToFile(phantomObjectVec, res)

disp('Results from Image Analysis: ');
disp('---------------------------- ');
disp(res.message); disp('');

load param.mat;
if (p.useGcMat)
    fid = fopen('phantomResultScan.txt', 'wt');
else
    fid = fopen('phantomResultField.txt', 'wt');
end

for i = 1:length(phantomObjectVec)
    
	if (strcmp(phantomObjectVec(i).type,'POINT_TARGET'))
        % profiles
        lat         = phantomObjectVec(i).profile1(1:end-2);
        rad         = phantomObjectVec(i).profile2(1:end-2);
        beams       = phantomObjectVec(i).profile1(end):phantomObjectVec(i).profile1(end) + length(lat) - 1;
        samples     = phantomObjectVec(i).profile2(end):phantomObjectVec(i).profile2(end) + length(rad) - 1;
        att         = phantomObjectVec(i).profile1(end-1);
        att_lat     = att*ones(1,length(lat)); 
        att_rad     = att*ones(1,length(rad));
        posX        = phantomObjectVec(i).posX*100;
        posY        = phantomObjectVec(i).posY*100;
        lengthVal   = phantomObjectVec(i).values1(end);
                
        c = [];
        x = [];
        y = [];
        for d = 1:round(length(phantomObjectVec(i).values2)/lengthVal)
            c = [c; phantomObjectVec(i).values1((1+(d-1)*lengthVal):(d*lengthVal))];
            x = [x; phantomObjectVec(i).values2((1+(d-1)*lengthVal):(d*lengthVal))];
            y = [y; phantomObjectVec(i).values3((1+(d-1)*lengthVal):(d*lengthVal))];
        end
        
        x = x*100;
        y = y*100;
  
        X= [];
        Y= [];
        C= [];  
        for j=1:size(x,2)-1
            for k = 1:size(x,1)-1
                temp_x = [x(k,j) x(k,j+1) x(k+1,j+1) x(k+1,j)];
                X = [X temp_x'];
                temp_y = [y(k,j) y(k,j+1) y(k+1,j+1) y(k+1,j)];
                Y = [Y temp_y'];
                temp_c = [c(k,j) c(k,j+1) c(k+1,j+1) c(k+1,j)];
                C = [C temp_c'];
            end				   
        end

        theText = sprintf(' -6 dB from\n highest level');
        
        hfig = figure();
        set(hfig, 'position', [360 278 560 420]);

        yC  = length(lat);      xC  = length(beams);	rC = max(yC,xC);
        yC  = yC/rC;			xC  = xC/rC;
        x0  = 0.10;             y0  = 0.10;             % start values
        xT  = 1.0 - 2*x0; 		yT  = 1.0 - 2*y0;       % total sizes	
        PDist = 0.005;                                  % half spacing
        xS  = 0.25*xT;       yS  = 0.25*yT;          % small row sizes (in % of available)		
        xM  = xT-xS; yM = yT-yS;           %xC*(1-yS)*xT;    yM  = yC*(1-yS)*yT;										
        xTot = x0 + xS + xM + x0;	
        yTot = y0 + yS + yM + x0;
        Amain   = [x0 y0+yS+PDist xM-PDist yM-PDist];
        ACbar   = [x0+xM+PDist y0 xS-PDist yS-PDist];
        Aright  = [x0+xM+PDist y0+yS+PDist xS-PDist yM-PDist];	
        Alow    = [x0 y0 xM-PDist yS-PDist];
        hMain   = axes('position',Amain);							
        hCbar   = axes('position',ACbar); 
        hRight  = axes('position',Aright);							
        hLow    = axes('position',Alow);
        h       = [hRight; hMain; hCbar; hLow];
        
        axes(hMain);
        hp = fill(X,Y,C);
        colormap(gray(255))
        axis([min(min(X))-0.05 max(max(X))+0.05 min(min(Y))-0.05 max(max(Y))+0.05]);
        set(hp,'EdgeColor','interp')
        set(hMain,'YDir','reverse')
        set(hMain,'XAxisLocation','top')
        ylabel('Depth [cm]');								
        xlabel('[cm]');

        axes(hLow)
        plot(beams,lat,'LineWidth',2)
        hold on;
        plot(beams,att_lat, 'k');
        axis([beams(1)-1 beams(end)+1 min(lat)-5 max(lat)+5]);
        text(beams(end-2),att,theText, 'VerticalAlignment', 'middle');
        xlabel('Beams')									
        ylabel('[dB]')	
        hold off;
        grid(hLow, 'on');

        axes(hRight)
        hR = plot(rad,samples,'LineWidth',2);
        hold on;
        plot(att_rad, samples, 'k');
        axis([min(rad)-5 max(rad)+5 samples(1)-1 samples(end)+1]);
        text(att, samples(end-2),theText, 'HorizontalAlignment', 'left');
        ylabel('Sample')									
        xlabel('[dB]')
        hold off;
        grid(hRight, 'on');

        set(hRight,'XDir','reverse')						
        set(hRight,'YDir','reverse')
        set(hRight,'YAxisLocation','right')				
        set(hRight,'XAxisLocation','top')

        axes(hCbar)
        % Display image
        pcolor(info.x_scan,info.y_scan,data');
        shading interp; colormap(gray(256));
        axis equal; axis ij;
        text(phantomObjectVec(i).posX-0.003, phantomObjectVec(i).posY,'X','Color', 'r', 'FontWeight', 'bold');
        set(hCbar, 'Xtick',[]);
        set(hCbar, 'Ytick',[]);
    end
end

if (p.useGcMat)
    fprintf(fid,'Results from Image Analysis, scanner version: \n---------------------------- \n \n');
else
    fprintf(fid,'Results from Image Analysis, field version: \n---------------------------- \n \n');
end

fprintf(fid,res.message);
fprintf(fid,'\n \n');

for j = 1:length(phantomObjectVec)
    
    if (phantomObjectVec(j).latRes ~= -1)
        s1 = [num2str(phantomObjectVec(j).latRes,'%.4f') ' beams           =>        ' num2str(phantomObjectVec(j).latResmm,'%.4f') ' mm'];
    else
        s1 = 'Not measurable.';
    end
    
    if (phantomObjectVec(j).radRes ~= -1)
        s2 = [num2str(phantomObjectVec(j).radRes,'%.4f') ' samples         =>        ' num2str(phantomObjectVec(j).radResmm,'%.4f') ' mm'];
    else
        s2 = 'Not measurable.';
    end
    
    if (strcmp(phantomObjectVec(j).type, 'POINT_TARGET'))
        phantomObjects = sprintf('Phatom no. %d: \t Type: \t\t\t\t\t %s \n \t\t\t\t Center point: \t\t\t (beam, sample): (%d,%d) => (x,y): (%.2f,%.2f) cm \n \t\t\t\t Mean intensity: \t\t %d \n \t\t\t\t Lateral resolution: \t %s \n \t\t\t\t Radial resolution:  \t %s \n'...
        , j, phantomObjectVec(j).type,  phantomObjectVec(j).beam, phantomObjectVec(j).sample, phantomObjectVec(j).posX*100 ...
        , phantomObjectVec(j).posY*100, round(phantomObjectVec(j).meanInt), s1, s2);

        fprintf(fid,'Phatom no. %d: \t Type: \t\t\t\t %s \n \t\t Center point: \t\t\t (beam, sample): \t\t (%d,%d) \n \t\t\t\t\t\t (x,y): \t\t\t (%.2f,%.2f) cm \n \t\t Mean intensity: \t\t %d \n \t\t Lateral resolution: \t\t %s \n \t\t Radial resolution:  \t\t %s \n \n'...
        , j, phantomObjectVec(j).type,  phantomObjectVec(j).beam, phantomObjectVec(j).sample, phantomObjectVec(j).posX*100 ...
        , phantomObjectVec(j).posY*100, round(phantomObjectVec(j).meanInt), s1, s2);
    else      
        phantomObjects = sprintf('Phatom no. %d: \t Type: \t\t\t\t\t %s \n \t\t\t\t Center point: \t\t\t (beam, sample): (%d,%d) => (x,y): (%.2f,%.2f) cm \n \t\t\t\t Mean intensity: \t\t %d \n \t\t\t\t Lateral resolution: \t %s \n \t\t\t\t Radial resolution:  \t %s \n \t\t\t\t Contrast resolution: \t %.2f dB \n'...
        , j, phantomObjectVec(j).type,  phantomObjectVec(j).beam, phantomObjectVec(j).sample, phantomObjectVec(j).posX*100 ...
        , phantomObjectVec(j).posY*100, round(phantomObjectVec(j).meanInt), s1, s2, phantomObjectVec(j).contrastRes_speckle);

        fprintf(fid,'Phatom no. %d: \t Type: \t\t\t\t %s \n \t\t Center point: \t\t\t (beam, sample): \t\t (%d,%d) \n \t\t\t\t\t\t (x,y): \t\t\t (%.2f,%.2f) cm \n \t\t Mean intensity: \t\t %d \n \t\t Lateral resolution: \t\t %s \n \t\t Radial resolution:  \t\t %s \n \t\t Contrast resolution \t\t %.2f dB \n \n'...
        , j, phantomObjectVec(j).type,  phantomObjectVec(j).beam, phantomObjectVec(j).sample, phantomObjectVec(j).posX*100 ...
        , phantomObjectVec(j).posY*100, round(phantomObjectVec(j).meanInt), s1, s2, phantomObjectVec(j).contrastRes_speckle);
    end

    disp(phantomObjects);
end

fclose(fid);

% Gain distribution
maxPreComp          = hCompInverse(255.0,info.preComp);
gainDistribution    = zeros(size(res.gainDist.gainDist1));
gainDistWithPT      = zeros(size(res.gainDist.gainDist3));

for i = 1:length(res.gainDist.gainDist1)
    valuePreComp    = hCompInverse(res.gainDist.gainDist1(i),info.preComp);
    dBPreComp       = 20*log10(valuePreComp/maxPreComp);
    
    gainDistribution(i) = dBPreComp;
end

for i = 1:length(res.gainDist.gainDist3)
    valuePreComp    = hCompInverse(res.gainDist.gainDist3(i),info.preComp);
    dBPreComp       = 20*log10(valuePreComp/maxPreComp);
    
    gainDistWithPT(i) = dBPreComp;
end

yCoord          = res.gainDist.gainDist2*100;
yCoordWithPT    = res.gainDist.gainDist4*100;

gainDist_smooth = smooth(gainDistribution,55);
gainDistWithPT_smooth = smooth(gainDistWithPT,20);
figure('position', [360 80 400 560]);
pos = [0.15 0.1 0.7 0.85];
hGD = axes('position', pos);
plot(gainDist_smooth,yCoord, 'LineWidth', 2);			
hold on;
plot(gainDistWithPT_smooth,yCoordWithPT, '--r');		
hold off;
legend('only speckle','with vertical point targets', 'Location', 'SouthEast')
axis([-68 -9 yCoord(1) yCoord(end)]);
title('Gain distribution');		
ylabel('Depth [cm]');		
xlabel('Intensity level [dB]');
set(hGD,'YDir','reverse');
