% ANALYSIS OF IMAGE
%
% image analysis and probeContact

%% Set parameters
p = struct();
p.useGcMat          = 1;
p.attenuation_dB    = 6;
p.radialDistance    = 0.01;
p.lateralDistance   = 0.02;

%% Loading parameters gcMat
h               = gcmatcontrol(1);
iq              = gcgetframedata(h,'IQ',1);

info            = struct();
info.gridSize   = gcudtparam(h,'iq','GridSize');
info.preComp    = gcudtparam(h,'tissue','PreCompression');

env             = abs(iq)/max(max(abs(iq)));
data            = hComp(env,info.preComp);

startDepth      = getparam('StartDepthIQ');
endDepth        = getparam('EndDepthIQ');
width           = gcudtparam(h,'iq','Width');
tilt            = gcudtparam(h,'iq','Tilt');
noBeams         = double(info.gridSize(2));
deltaAngle      = width/noBeams;
startAngle      = -width/2 + 0*deltaAngle + tilt;       % beam no. 0    (first beam)
endAngle        = -width/2 + noBeams*deltaAngle + tilt;       % beam no. 155  (last beam)

info.useGcMat   = p.useGcMat;
info.names      = {'PhantomShape' 'PhantomShapeNorth' 'PhantomShapeEast' 'PhantomShapeSouth' 'PhantomShapeWest'};

% Create axes
c               = 1540;
f2              = (size(data,1)-1)/(2*endDepth/c);
x_axis_theta    = linspace(startAngle,endAngle, size(data,2));    % [rad]
z_axis          = (c/2*(0:size(data,1)-1)/f2);                               % [mm]
 % Scanconvertion
[r,th]          = meshgrid(z_axis,x_axis_theta);
[info.y_scan,info.x_scan] = pol2cart(th,r);

hScan = figure(6);
pcolor(info.x_scan*100,info.y_scan*100,data');
shading interp; colormap(gray(256));
axis equal; axis ij;
xlabel('Azimuth [cm]');ylabel('Depth [cm]');
set(gca,'Color',[0 0 0])
axis([-10 10 0 16]);

for t = 1:length(info.names)
    posPhantom = GetPolygon(info.names(t));
    if (posPhantom(1,1) < 0)
        rectangle('Position', [posPhantom(1,1)*100 posPhantom(1,2)*100 1 1], 'EdgeColor', 'r', 'LineWidth', 1.5)
    else
        rectangle('Position', [posPhantom(4,1)*100 posPhantom(4,2)*100 1 1], 'EdgeColor', 'r', 'LineWidth', 1.5)
    end    
end

save param.mat data info p;

% Compute params
res     = struct();
h_wait  = waitbar(0,'Please wait...');
set(h_wait, 'position', [300 100 270 56.25]);

phantomObject = analysisOfFrames();
cnt = length(phantomObject);
waitbar(1/5)

[phantomObjectType, phantomObjectX, phantomObjectY] = textread('phantomParam.txt', '%*s %*s %d %*s %*s %f %*s %*s %f');
phantomObject = analysisOfGivenPhantomObjects(phantomObject,phantomObjectType,phantomObjectX,phantomObjectY);
waitbar(2/5)

res.message = allPhantomsOK(phantomObject);
waitbar(3/5)

if (cnt == 5)		% only run method if the 5 first point targets have been found
    res.gainDist = gainDistribution(phantomObject);
    
    % calculating distances between some of the point targets
    res.measDist = measurementOfDistances(phantomObject);
end
waitbar(4/5)

dumpToFile(phantomObject, res);
waitbar(5/5)

close(h_wait)

% including ProbeContact, change to your path of ProbeContact
addpath('C:\Documents and Settings\Cecilie\My Documents\Skole\2009\Master\Prog\ProbeContactMatlab\');
probeContact;
