% ANALYSIS OF IMAGE FOR FIELD

function imageAnalyzerForField(folderName)

%% Set parameters
p = struct();
p.useGcMat          = 0;
p.attenuation_dB    = 6;
p.radialDistance    = 0.01;
p.lateralDistance   = 0.02;

%% Loading parameters
if nargin < 1,
    folderName      = 'W:\Field\Phantoms\A';
end
fileName            = [folderName, '\frame1.mat'];
load(fileName);
data                = fromPhantom.data;

info                = struct();
info.preComp        = 0.0600;
info.gridSize       = size(data);
info.y_scan         = fromPhantom.x_scan;
info.x_scan         = fromPhantom.y_scan;
info.useGcMat       = p.useGcMat;
info.names          = {'PhantomShape' 'PhantomShapeNorth' 'PhantomShapeEast' 'PhantomShapeSouth' 'PhantomShapeWest'};

figure(6);
pcolor(info.x_scan*100,info.y_scan*100,data');
shading interp; colormap(gray(256));
axis equal; axis ij;
xlabel('Azimuth [cm]');ylabel('Depth [cm]');
set(gca,'Color',[0 0 0])
axis([-10 10 0 16]);
for t = 1:length(info.names)
    posPhantom = GetPolygon(info.names(t));
    if (posPhantom(1,1) < 0)
        rectangle('Position', [posPhantom(1,1)*100 posPhantom(1,2)*100 1 1], 'EdgeColor', 'r')
    else
        rectangle('Position', [posPhantom(4,1)*100 posPhantom(4,2)*100 1 1], 'EdgeColor', 'r')
    end    
end

save param.mat data info p;

% Compute params
h_wait = waitbar(0,'Please wait...');
set(h_wait, 'position', [300 100 270 56.25]);

phantomObject = analysisOfFrames();
cnt = length(phantomObject);
waitbar(1/5)

[phantomObjectType, phantomObjectX, phantomObjectY] = textread('phantomParam.txt', '%*s %*s %d %*s %*s %f %*s %*s %f');
phantomObject = analysisOfGivenPhantomObjects(phantomObject,phantomObjectType,phantomObjectX,phantomObjectY);
waitbar(2/5)

res.message = allPhantomsOK(phantomObject);
waitbar(3/5)

if (cnt == 5)		% only run method if the 5 first point targets have been found
    res.gainDist = gainDistribution(phantomObject);
    
    % calculating distances between some of the point targets
    res.measDist = measurementOfDistances(phantomObject);
end
waitbar(4/5)

dumpToFile(phantomObject, res);
waitbar(5/5)

close(h_wait)
