function phantomObject = pointTargetCharacteristics(phantomObject, startPt, endPt)

info = struct();

load param.mat;

maxi = 0;
maxiIndex = 0;

startB  = round(startPt.beams);
startS  = round(startPt.samples);
endB    = round(endPt.beams);
endS	= round(endPt.samples);

phantomObject.values1   = [];
phantomObject.values2   = [];
phantomObject.values3   = [];
phantomObject.profile1  = [];
phantomObject.profile2  = [];

tempProfile1 = [];              % intValue for increasing beams
tempProfile2 = [];              % samples
tempProfile3 = [];              % intValue for increasing samples
tempProfile4 = [];              % beams

temp = zeros(endS-startS+1,endB-startB+1);

for b = startB:endB
    for s = startS:endS
        temp(s-startS+1,b-startB+1) = data(s,b);       % desimaltall
    end
end

[maxS,maxB] = find(temp == max(max(temp)));

% Lateral, choose the beam with largest intensity + register all intensity levels
% Only look for max in a small region around maxpoint
newStartS   = (startS + maxS - 1) - round((endS-startS)/8);
newEndS     = (startS + maxS - 1) + round((endS-startS)/8);

for b = startB:endB
    for s = newStartS:newEndS
        valueCenter = data(s,b);
        if (valueCenter > maxi)
            maxi        = valueCenter;
            maxiIndex   = s;
        end
    end
    tempProfile1 = [tempProfile1 maxi];
    tempProfile2 = [tempProfile2 maxiIndex];
    maxi = 0;
end

maxiIndex = 0;
% 
% Radial, choose the sample with largest intensity
newStartB = (startB + maxB - 1) - round((endB-startB)/8);
newEndB = (startB + maxB - 1) + round((endB-startB)/8);
for s = startS:endS
    for b = newStartB:newEndB
        valueCenter = data(s,b);
        if (valueCenter > maxi)
            maxi        = valueCenter;
            maxiIndex   = b;
        end
    end
    tempProfile3 = [tempProfile3 maxi];
    tempProfile4 = [tempProfile4 maxiIndex];
    maxi = 0;
end


% save all intensity values for plot
for s = startS:endS
    for b = startB:endB
        valueCenter           = data(s,b);
        [tmp_PS.x, tmp_PS.y]  = fromBeamSpace(s,b,info);

        phantomObject.values1 = [phantomObject.values1 valueCenter];
        phantomObject.values2 = [phantomObject.values2 tmp_PS.x];
        phantomObject.values3 = [phantomObject.values3 tmp_PS.y];
    end
end

% last element in values1 is the length of beams
phantomObject.values1 = [phantomObject.values1 round(endPt.beams)-round(startPt.beams)+1];

% m = 1: lateral, m = 3: radial
for m = 1:2:3
    
    maxInt = 0;
		
    if (m == 1)
        tempProfileA    = tempProfile1;
        tempProfileB    = tempProfile2;
    else
        tempProfileA    = tempProfile3;
        tempProfileB    = tempProfile4;
    end

    % make profile for the beams and samples with largest intensity
    for n = 1:length(tempProfileA)
        if (tempProfileA(n) > maxInt)
            maxInt	= tempProfileA(n);
            index	= n;
        end
    end

    % find X dB attenuation on each side of maximum point
    maxIntPreComp   = hCompInverse(maxInt,info.preComp);
    attPreComp      = maxIntPreComp*(10.^(-p.attenuation_dB/20.0));
    att             = hComp(attPreComp,info.preComp);
  
    % POSITIVE SIDE
    crossing	= false;
    t			= index;
   
    while (~crossing)
        if ( tempProfileA(t) < att || t == length(tempProfileA) )
           crossing = true;
        else
            t = t + 1;
        end
    end

    indexP = t;

    % determine lateral and radial resolution
    if (m==1)
        [x0, y0] = fromBeamSpace(tempProfileB(t-1), startB + t-1,info);
        [x1, y1] = fromBeamSpace(tempProfileB(t), startB + t,info);
    else
        [y0, x0] = fromBeamSpace(startS + t-1, tempProfileB(index),info);
        [y1, x1] = fromBeamSpace(startS + t, tempProfileB(index),info);
    end

    h0	= tempProfileA(t-1);
    h1	= tempProfileA(t);
    h	= att;

    % linear interpolation
    xUpper		= x0 + (h-h0)*((x1-x0)/(h1-h0));
    yUpper_toBS	= y0 + (xUpper-x0)*((y1-y0)/(x1-x0));


    % NEGATIVE SIDE
    crossing	= false;
    t			= index;
    while (~crossing)
        if ( tempProfileA(t) < att || t == 1)
            crossing = true;
        else
            t = t - 1;
        end
    end

    indexN = t;

    if (m==1)
        [x0, y0] = fromBeamSpace(tempProfileB(t), startB + t,info);
        [x1, y1] = fromBeamSpace(tempProfileB(t+1), startB + t+1,info);
    else
        [y0, x0] = fromBeamSpace(startS + t, tempProfileB(index),info);
        [y1, x1] = fromBeamSpace(startS + t+1, tempProfileB(index),info);
    end

    h0	= tempProfileA(t);
    h1	= tempProfileA(t+1);
    h	= att;

    % linear interpolation
    xLower		= x0 + (h-h0)*((x1-x0)/(h1-h0));	
    yLower_toBS	= y0 + (xLower-x0)*((y1-y0)/(x1-x0));

    if (m == 1)
        % if X dB is on the edges, it is not good enough
        if( indexP == length(tempProfileA) || indexN == 0 )
            phantomObject.latRes    = -1;
            phantomObject.latResmm  = -1;
        end

        [upper.samples, upper.beams] = toBeamSpace(xUpper, yUpper_toBS,info);
        [lower.samples, lower.beams] = toBeamSpace(xLower, yLower_toBS,info); 

        diffB   = abs(upper.beams - lower.beams);
        diff	= abs(xUpper - xLower)*1000;

        phantomObject.latRes    = diffB;
        phantomObject.latResmm  = diff;
        sb.beams = startB + index - 1;
    else
        % if X dB is on the edges, it is not good enough
        if( indexP == length(tempProfileA) || indexN == 0 )
            phantomObject.radRes    = -1;
            phantomObject.radResmm  = -1;
        end

        [upper.samples, upper.beams] = toBeamSpace(yUpper_toBS, xUpper, info);
        [lower.samples, lower.beams] = toBeamSpace(yLower_toBS, xLower, info); 

        diffS	= abs(upper.samples - lower.samples);
        diff	= abs(xUpper - xLower)*1000;

        phantomObject.radRes    = diffS;
        phantomObject.radResmm  = diff;
        sb.samples = startS + index - 1;
    end

end

maxPreComp = hCompInverse(255.0,info.preComp);

for i = 1:length(tempProfile1)
    valuePreComp    = hCompInverse(tempProfile1(i),info.preComp);
    dBPreComp       = 20*log10(valuePreComp/maxPreComp);
    
    phantomObject.profile1 = [phantomObject.profile1 dBPreComp];
end

for i = 1:length(tempProfile3)
    valuePreComp	= hCompInverse(tempProfile3(i),info.preComp);
    dBPreComp       = 20*log10(valuePreComp/maxPreComp);

    phantomObject.profile2 = [phantomObject.profile2 dBPreComp];
end

% the last but one element in profiles is the attenuation
attPreComp = hCompInverse(att,info.preComp);
phantomObject.profile1 = [phantomObject.profile1 20*log10(attPreComp/maxPreComp)];	% same for m = 1 and m = 2
phantomObject.profile2 = [phantomObject.profile2 20*log10(attPreComp/maxPreComp)];

% last element in profiles is the start beam and start sample
phantomObject.profile1 = [phantomObject.profile1 round(startPt.beams)];
phantomObject.profile2 = [phantomObject.profile2 round(startPt.samples)];

[xy.x, xy.y] = fromBeamSpace(sb.samples, sb.beams, info);

phantomObject.beam      = sb.beams;
phantomObject.sample    = sb.samples;
phantomObject.posX      = xy.x;
phantomObject.posY      = xy.y;
phantomObject.type      = 'POINT_TARGET';

% Mean intensity calculations
if (phantomObject.latRes == -1 || phantomObject.radRes == -1)
    phantomObject.meanInt = 0;
else
    startB  = phantomObject.beam - floor(phantomObject.latRes/2 + 0.5);
    endB	= phantomObject.beam + floor(phantomObject.latRes/2 + 0.5);
    startS  = phantomObject.sample - floor(phantomObject.radRes/2 + 0.5);
    endS	= phantomObject.sample + floor(phantomObject.radRes/2 + 0.5);

    meanV = 0;
    cntPT = 0;
    
    for b = startB:endB
        for s = startS:endS
            if( (b==startB&&s==startS) || (b==startB&&s==endS) || (b==endB&&s==startS) || (b==endB&&s==endS) )
                % ikke noe
            else
                valueCenter = data(s,b);
                meanV       = meanV + valueCenter;
                cntPT       = cntPT + 1;
            end
        end
    end

    if (cntPT == 0)
        meanV = 0;
    else
        meanV = meanV/cntPT;
    end

    phantomObject.meanInt = meanV;
end
