%       SPATIAL VARIANCE FOR FIELD
% ----------------------------------------
%   Cecilie ins Simpson, 06.0506.09

function spatialVarianceForField(folderName,MLA,withSpeckle,useMorePT,makeMovie,iqData)
%% Set parameters
p                   = struct();
p.useGcMat          = 1;
p.attenuation_dB    = 6;
p.radialDistance    = 0.01;
p.lateralDistance   = 0.02;
widthDegrees        = 35;
frames              = 99;

%% Set desired calculations
if nargin < 1,
    folderName      = 'W:\Field\Phantoms\A';
    p.N_MLA         = 1;
    withSpeckle     = 0;        % calculate corr. coeff. for both PT ROI and speckle ROI, PT = point target
    useMorePT       = 0;        % calculate corr. coeff. for 3 PT in the image
    makeMovie       = 0;        % make 2 movies, one of moving PT and one closeup of PT 
    iqData          = 0;        % calculate corr. coeff using IQ-data (and not beamspace tissue data)
else
    p.N_MLA         = MLA;
end

interpSizeS = 5;
interpSizeB = 20;

%% Loading parameters gcMat
fileName    = [folderName, '\frame1.mat'];
load(fileName);

% Different info
info            = struct();
info.preComp    = 0.0600;

% Different calculations of data
if (iqData)
    iq          = fromPhantom.iqdata2;
    env         = abs(iq)/max(max(abs(iq)));
    data        = hComp(env,info.preComp);
else
    data        = fromPhantom.data;
end

info.gridSize   = size(data);
info.y_scan     = fromPhantom.x_scan;
info.x_scan     = fromPhantom.y_scan;
info.useGcMat   = p.useGcMat;
if (useMorePT)
    info.names  = {'PhantomShape' 'PhantomShapeNorth' 'PhantomShapeSouth'};
else
    info.names  = {'PhantomShape'};
end
info.namesMean  = {'PhantomShape' 'PhantomShapeNorth' 'PhantomShapeSouth' 'PhantomShapeExtra1' 'PhantomShapeExtra2' 'PhantomShapeExtra3'};

width           = widthDegrees*pi/180;
tilt            = 0;
noSamples       = double(info.gridSize(1));
noBeams         = double(info.gridSize(2));
deltaAngle      = width/(noBeams-1);
startAngle      = -width/2 + 0*deltaAngle + tilt;       % beam no. 0    (first beam)
endAngle        = -width/2 + (noBeams-1)*deltaAngle + tilt; % beam no. 155  (last beam)

theta_receive   = linspace(startAngle,endAngle,noBeams);
d_theta_receive = theta_receive(2)-theta_receive(1);
theta_emit_start= theta_receive(1) + (p.N_MLA-1)/2*d_theta_receive;
theta_emit_end  = theta_receive(end) - (p.N_MLA-1)/2*d_theta_receive;
noBeams_emit    = noBeams/p.N_MLA;
theta_emit      = linspace(theta_emit_start, theta_emit_end, noBeams_emit);

save param.mat data info p;

%% Calculations for frame closest to theta emit = reference frame
compareX        = struct();
currentCenter   = struct();

phantomPosition                         = GetPolygon(info.names(1));
[point1_BS.samples, point1_BS.beams]    = toBeamSpace(phantomPosition(1,1), phantomPosition(1,2),info);
[point2_BS.samples, point2_BS.beams]    = toBeamSpace(phantomPosition(2,1), phantomPosition(2,2),info);   
[point3_BS.samples, point3_BS.beams]    = toBeamSpace(phantomPosition(3,1), phantomPosition(3,2),info);
[point4_BS.samples, point4_BS.beams]    = toBeamSpace(phantomPosition(4,1), phantomPosition(4,2),info);
p.sizeB = round(abs(point3_BS.beams   - point2_BS.beams));
p.sizeS = round(abs(point2_BS.samples - point1_BS.samples));
% Adjusting to better region
p.sizeB = p.sizeB + 1;
p.sizeS = p.sizeS - 8;

startB	= minValue(point1_BS.beams,   point2_BS.beams,   point3_BS.beams,   point4_BS.beams);
startS  = minValue(point1_BS.samples, point2_BS.samples, point3_BS.samples, point4_BS.samples);
endB    = maxValue(point1_BS.beams,   point2_BS.beams,   point3_BS.beams,   point4_BS.beams);
endS	= maxValue(point1_BS.samples, point2_BS.samples, point3_BS.samples, point4_BS.samples);

% Check for uncorrect beams and samples
if (startB <= 0)
    startB = 1;
end
if (startS <= 0)
    startS = 1;
end
if (endB > info.gridSize(2) - 1)
    endB = info.gridSize(2)- 1;
end
if (endS > info.gridSize(1) - 1)
    endS = info.gridSize(1) - 1;
end

% Find which frame to compare against
h_wait  = waitbar(0,'Analyzing frames - part 1, please wait...');
testF   = 40;
for f = 1:testF   % only the first
    fileName    = [folderName, '\frame', num2str(f),'.mat'];
    load(fileName);
    if (iqData)
        iq      = fromPhantom.iqdata2;
        env     = abs(iq)/max(max(abs(iq)));
        data    = hComp(env,info.preComp);
    else
        data    = fromPhantom.data;
    end
    info.y_scan = fromPhantom.x_scan;
    info.x_scan = fromPhantom.y_scan;
    [cS,cB]     = find(data(startS:endS,startB:endB) == max(max(data(startS:endS,startB:endB))));
    centerB     = startB + cB(1) - 1;
    centerS     = startS + cS(1) - 1;
    smallSizeS  = round(p.sizeS/9);
    smallSizeB  = p.sizeB;
    ROI2        = data(centerS-smallSizeS:centerS+smallSizeS,centerB-smallSizeB:centerB+smallSizeB);
        
    % Lateral
    [x1,y1]     = fromBeamSpace(centerS,centerB-smallSizeB, info);
    [x2,y2]     = fromBeamSpace(centerS,centerB+smallSizeB, info);
    xShort      = linspace(x1,x2,size(ROI2,2));
    xLong       = linspace(x1,x2,40*size(ROI2,2));

    [maxS,maxB] = find(ROI2 == max(max(ROI2)));
    temp_lat    = ROI2((maxS(1)-1):(maxS(1)+1),:);
    temp_lat    = mean(temp_lat);
    lat         = interp1(xShort,temp_lat,xLong,'spline');
    
    [lat_value,lat_index] = max(lat); 
    threshold   = lat_value*10^(-1/10); 
    start_index = find(lat(1:lat_index) < threshold);
    if(isempty(start_index))
        start_index = 1;
    else
        start_index = start_index(end);
        if (start_index < 1)
            start_index = 1;
        end
    end
    end_index   = find(lat(lat_index:end) < threshold);
    if(isempty(end_index))
        end_index = length(lat);
    else
        end_index = end_index(1) + lat_index - 1;
        if (end_index > length(lat))
            end_index = length(lat);
        end
    end
    
    findF(f).xLong2 = xLong(start_index:end_index);
        
    waitbar(f/testF)
end
close(h_wait)

% Find the closest frame to theta_emit
min_val = 100;
max_val = 0;
for f = 1:testF
    val = min(abs(findF(f).xLong2(end) - findF(f).xLong2(1)));
    if (val < min_val)
        min_val     = val;
        frame_comp  = f;
    end
end

fileName    = [folderName, '\frame', num2str(frame_comp),'.mat'];
load(fileName);
if (iqData)
    iq      = fromPhantom.iqdata2;
    env     = abs(iq)/max(max(abs(iq)));
    data    = hComp(env,info.preComp);
else
    data    = fromPhantom.data;
end
save param.mat data info p;

phantomObject = analysisOfFrames();
for ph = 1:length(phantomObject) 
    currentCenter(ph).beam      = phantomObject(ph).beam;
    currentCenter(ph).sample    = phantomObject(ph).sample;
end

% Reference frame calculations
for ph = 1:length(phantomObject)

    centerB = phantomObject(ph).beam;
    centerS = phantomObject(ph).sample;
    startB  = centerB - round(p.sizeB/2);
    startS  = centerS - round(p.sizeS/2);
    endB    = centerB + ceil(p.sizeB/2) - 1;
    endS    = centerS + ceil(p.sizeS/2) - 1;
    
    if (startB <= 0)
        endB    = endB + abs(startB) + 1;
        startB  = 1;
    end
    if (startS <= 0)
        endS    = endS + abs(endS) + 1;
        startS  = 1;
    end
    if (endB > info.gridSize(2) - 1)
        startB  = startB - (endB-info.gridSize(2)-1);
        endB    = info.gridSize(2)- 1;
    end
    if (endS > info.gridSize(1) - 1)
        startS  = startS - (endS-info.gridSize(1)-1);
        endS    = info.gridSize(1) - 1;
    end
        
    ROI     = data(startS:endS,startB:endB); 
    old_S   = startS:endS;
    old_B   = startB:endB;
    new_S   = linspace(startS,endS,interpSizeS*size(ROI,1));
    new_B   = linspace(startB,endB,interpSizeB*size(ROI,2));
    ROI_new = interp2(old_B,old_S,ROI,new_B,new_S');
     
    theta_first = startAngle + deltaAngle*(centerB - 1);
    compareX(ph).ROI_new = ROI_new;  
end

%% Calculate for different frames
sv              = struct(); % SV = spatial variance
compare         = struct();

if (makeMovie)
    %Stort omrde som er interpolert og kan brukes
    Nb          = 2.^nextpow2(2*p.sizeB)-6;
    Ns          = 2.^nextpow2(p.sizeS)-20;
    centerB     = currentCenter(1).beam;
    centerS     = currentCenter(1).sample;
    SstartB     = centerB - round(Nb/2);
    SstartS     = centerS - round(Ns/2);
    SendB       = centerB + round(Nb/2) - 1;
    SendS       = centerS + round(Ns/2) - 1;
    data_new    = data(SstartS:SendS,SstartB:SendB);
    old_SS      = SstartS:SendS;
    old_BS      = SstartB:SendB;
    new_SS      = linspace(SstartS,SendS,interpSizeS*size(data_new,1));
    new_BB      = linspace(SstartB,SendB,interpSizeB*size(data_new,2));
    data2       = interp2(old_BS,old_SS,data_new,new_BB,new_SS');
end

h_wait = waitbar(0,'Analyzing frames - part 2, please wait...');

for f = 1:(frames - frame_comp)
    
    if (round(frames/2) > frame_comp)       % use frames after frame_comp
        file_name=[folderName,'\frame',num2str(f+frame_comp-1),'.mat'];
    else
        file_name=[folderName,'\frame',num2str(1+frame_comp-f),'.mat'];
    end
    
    if exist(file_name)

        load(file_name);       
        if (iqData)
            iq          = fromPhantom.iqdata2;
            env         = abs(iq)/max(max(abs(iq)));
            data        = hComp(env,info.preComp);
        else
            data        = fromPhantom.data;
        end
        info.y_scan     = fromPhantom.x_scan;
        info.x_scan     = fromPhantom.y_scan;
                
        if (makeMovie)
            data_new    = data(SstartS:SendS,SstartB:SendB);
            data2       = interp2(old_BS,old_SS,data_new,new_BB,new_SS');
        end
        
        % Distance measurement
        for n = 1:length(info.namesMean)
            dist = calcDistSV(p,info,sv,data,f,n);
            compare(n).centerB = dist.centerB;
            compare(n).centerS = dist.centerS;
            compare(n).x = dist.x;  
            compare(n).y = dist.y; 
            compare(n).lat = dist.lat2;
            compare(n).xLong = dist.xLong2;
        end
                     
        for ph = 1:length(info.names)
             
            Nb  = 2.^nextpow2(p.sizeB);
            Ns  = 2.^nextpow2(p.sizeS);

            if Nb < 10
                Nb = Nb + 2;
            end
            if (Nb <= p.sizeB + 1)
                Nb = Nb + 18;
            end

            % Bruker forrige punkspreders midtpunkt som utgangspunkt
            centerB = currentCenter(ph).beam;
            centerS = currentCenter(ph).sample;
            startB  = centerB - round(Nb/2);
            startS  = centerS - round(Ns/2);
            endB    = centerB + round(Nb/2) - 1;
            endS    = centerS + round(Ns/2) - 1;

            if (startB <= 0)
                endB    = endB + abs(startB) + 1;
                startB  = 1;
            end
            if (startS <= 0)
                endS    = endS + abs(endS) + 1;
                startS  = 1;
            end
            if (endB > info.gridSize(2) - 1)
                startB  = startB - (endB-(info.gridSize(2)-1));
                endB    = info.gridSize(2)- 1;
            end
            if (endS > info.gridSize(1) - 1)
                startS  = startS - (endS-(info.gridSize(1)-1));
                endS    = info.gridSize(1) - 1;
            end
            
            ROI = data(startS:endS,startB:endB);
            if (iqData)
                ROI_iq = iq(startS:endS,startB:endB);
            end
                
            old_S   = startS:endS;
            old_B   = startB:endB;
            new_S   = linspace(startS,endS,interpSizeS*size(ROI,1));
            new_B   = linspace(startB,endB,interpSizeB*size(ROI,2));
            ROI_new = interp2(old_B,old_S,ROI,new_B,new_S');
                        
            ROI_new_speckle = ROI_new;
            
            if (iqData)
                ROI_iq_new          = interp2(old_B,old_S,ROI_iq,new_B,new_S');
                ROI_iq_new_speckle  = ROI_iq_new;
            end
                        
            f1      = ROI_new - mean(mean(ROI_new));
            f2      = zeros(size(f1,1),size(f1,2));
            g       = size(compareX(ph).ROI_new);
            f2(1:g(1),1:g(2)) = compareX(ph).ROI_new - mean(mean(compareX(ph).ROI_new));
            N1      = size(ROI_new,1);
            N2      = size(ROI_new,2);
            fr_f1   = fft2(f1,N1,N2);
            fr_f2   = fft2(f2,N1,N2);
            fr_2conj= conj(fr_f2);
            fr      = (1/(N1*N2))*fr_f1.*fr_2conj;
            t       = ifft2(fr,N1,N2);
            [d1,d2] = find(t == max(max(t)));
                        
            Yb      = size(compareX(ph).ROI_new,2);
            Ys      = size(compareX(ph).ROI_new,1);
            
            % Check
            if (d1+Ys > size(ROI_new,1) || d2+Yb > size(ROI_new,2))
                % Find next largest number
                t_new           = t;
                t_new(d1,d2)    = 0;
                [d1,d2]         = find(t_new == max(max(t_new)));
            end
            if (d1+Ys > size(ROI_new,1))
                disp(['Mismatch for template matching for frame ', num2str(f)]);
                d1 = (size(ROI_new,1)-1) - Ys;
            end
            if (d2+Yb > size(ROI_new,2))
                disp(['Mismatch for template matching for frame ', num2str(f)]);
                d2 = (size(ROI_new,2)-1) - Yb;
            end
            
            [maxS,maxB] = find(ROI_new == max(max(ROI_new)));
            YsS = size(ROI_new,2);
            
            ROI_new = ROI_new(d1:d1+Ys-1,d2:d2+Yb-1);
            
            if (iqData)
                ROI_iq_new = ROI_iq_new(d1:d1+Ys-1,d2:d2+Yb-1);
            end  
            
            %Speckle ROI
            speckleSizeS        = 110;
            speckleSizeB        = 120;
            limitS              = maxS - 40;
            if (limitS > speckleSizeS)
                startSpeckleS   = limitS - speckleSizeS;
                endSpeckleS     = limitS - 1;
            else
                startSpeckleS   = 1;
                endSpeckleS     = speckleSizeS;
            end
            limitB              = round(speckleSizeB/2);
            if (maxB - limitB) < 1
                startSpeckleB   = 1;
                endSpeckleB     = speckleSizeB;
            elseif (maxB + limitB) > YsS
                startSpeckleB   = YsS - speckleSizeB;
                endSpeckleB     = YsS - 1;
            else
                startSpeckleB   = maxB - limitB;
                endSpeckleB     = maxB + limitB - 1;
            end
            
            ROI_new_speckle     = ROI_new_speckle(startSpeckleS:endSpeckleS,startSpeckleB:endSpeckleB);
            if (iqData)
                ROI_iq_new_speckle = ROI_iq_new_speckle(startSpeckleS:endSpeckleS,startSpeckleB:endSpeckleB);
            end 
            
            ROI         = ROI_new(1:interpSizeS:end,1:interpSizeB:end);
            [maxS,maxB] = find(ROI == max(max(ROI)));
            startB      = startB + round(d2/interpSizeB) - 1;
            startS      = startS + round(d1/interpSizeS) - 1;

            currentCenter(ph).beam      = startB + maxB(1) - 1;
            currentCenter(ph).sample    = startS + maxS(1) - 1;
            
            % Save      
            compare(ph).ROI_new         = ROI_new;
            compare(ph).ROI_new_speckle = ROI_new_speckle;
            
            if (makeMovie)
                compare(ph).data2       = data2;
            end   
            if (iqData)
                compare(ph).ROI_iq_new  = ROI_iq_new;
                compare(ph).ROI_iq_new_speckle = ROI_iq_new_speckle;
            end
        end       
        sv(f).compare = compare;            
    else
        disp(['Frame ',num2str(f+frame_comp-1),' or frame ',num2str(1+frame_comp-f),' missing'])
    end        
    waitbar(f/(frames-frame_comp))
end
close(h_wait)

%% Calculation of correlation coefficient and distance for every frame
for f = 1:length(sv)
    sumAlpha = 0;
    for n = 1:length(info.namesMean)
        firstX      = sv(1).compare(n).x;     
        diffX       = abs(firstX - sv(f).compare(n).x);       
        alpha       = atan(diffX/sv(1).compare(n).y);
        sumAlpha    = sumAlpha + alpha;
    end 
    sv(f).compare(1).angleDist = (sumAlpha)/length(info.namesMean);
    
    for ph = 1:length(info.names)
        % Correlation coeff
        if (iqData)
            a = sv(1).compare(ph).ROI_iq_new;
            b = sv(f).compare(ph).ROI_iq_new;
        else
            a = sv(1).compare(ph).ROI_new;
            b = sv(f).compare(ph).ROI_new;
        end
        a = a - mean2(a);
        b = b - mean2(b);      
        sv(f).compare(ph).r = sum(sum(a.*conj(b)))/sqrt(sum(sum(a.*conj(a)))*sum(sum(b.*conj(b))));
        
        % Correlation coeff SPECKLE
        if (iqData)
            a = sv(1).compare(ph).ROI_iq_new_speckle;
            b = sv(f).compare(ph).ROI_iq_new_speckle;
        else
            a = sv(1).compare(ph).ROI_new_speckle;
            b = sv(f).compare(ph).ROI_new_speckle;
        end
        a = a - mean2(a);
        b = b - mean2(b);     
        sv(f).compare(ph).r_speckle = sum(sum(a.*conj(b)))/sqrt(sum(sum(a.*conj(a)))*sum(sum(b.*conj(b))));

        % Distance probe moved
        distX = abs(sv(f).compare(ph).x - sv(1).compare(ph).x);
        distY = abs(sv(f).compare(ph).y - sv(1).compare(ph).y);
        sv(f).compare(ph).dist = sqrt(distX.^2 + distY.^2) * 1000;         % [mm], distance probe moved
    end     
end

%% Plots
out = struct();

for ph = 1:length(info.names)
    out(ph).r               = [];
    out(ph).r_speckle       = [];
    out(ph).dist            = [];
    out(ph).angleDist       = [];
    for index = 1:length(sv)
        out(ph).r           = [out(ph).r sv(index).compare(ph).r];
        out(ph).r_speckle   = [out(ph).r_speckle sv(index).compare(ph).r_speckle];
        out(ph).dist        = [out(ph).dist sv(index).compare(ph).dist];
        out(ph).angleDist   = [out(ph).angleDist sv(index).compare(ph).angleDist];
    end
end

% Theta_first must be corrected to include a emit beam
[val, pos]              = min(abs(theta_emit - theta_first));
theta_first             = theta_emit(pos);
theta_receive_degree    = (theta_first - theta_receive)*180/pi;
theta_emit_degree       = (theta_first - theta_emit)*180/pi;
theta_all               = out(1).angleDist*180/pi;

% Distance calculations, method 2 (the PT move exactly the same
% distance for each frame
beta                    = linspace(0,6,frames)*pi/180;
theta_all2              = beta(1:length(sv))*180/pi;

if (withSpeckle)
    figure;
    subplot(2,1,1)
    plot(theta_all,abs(out(1).r),'k.--','LineWidth',2)
    title(['Simulated image with ', num2str(info.gridSize(2)), ' beams'],'FontSize',12)
    xlabel('Distance from point target in reference frame [degree]','FontSize',12);
    ylabel('Correlation coefficient','FontSize',12)
    axis([-0.01 3.1 0.86 1])
    hold on;
    for i = 1:length(theta_receive_degree)
        if (theta_receive_degree(i) >= 0 && theta_receive_degree(i) <= 3.5)
            p1 = plot([theta_receive_degree(i) theta_receive_degree(i)],get(gca,'YLim'),'b--');
        end
    end
    for i = 1:length(theta_emit_degree)
        if (theta_emit_degree(i) >= 0 && theta_emit_degree(i) <= 3.5)
            p2 = plot([theta_emit_degree(i) theta_emit_degree(i)],get(gca,'YLim'),'r--');
        end
    end
    hold off;
    subplot(2,1,2)
    plot(theta_all,abs(out(1).r_speckle),'k.--','LineWidth',2)
    title('Speckle ROI','FontSize',12)
    xlabel('Distance from point target in reference frame [degree]','FontSize',12);
    ylabel('Correlation coefficient','FontSize',12)
    axis([-0.01 3.1 0.86 1])
    hold on;
    for i = 1:length(theta_receive_degree)
        if (theta_receive_degree(i) >= 0 && theta_receive_degree(i) <= 3.5)
            p1 = plot([theta_receive_degree(i) theta_receive_degree(i)],get(gca,'YLim'),'b--');
        end
    end
    for i = 1:length(theta_emit_degree)
        if (theta_emit_degree(i) >= 0 && theta_emit_degree(i) <= 3.5)
            p2 = plot([theta_emit_degree(i) theta_emit_degree(i)],get(gca,'YLim'),'r--');
        end
    end
    hold off;
else
    figure;
    p1 = plot(out(1).dist,out(1).r,'.--','LineWidth',2);
    xlabel('Distance from point target in reference frame [mm]','FontSize',12);
    ylabel('Correlation coefficient','FontSize',12);
    axis([-0.01 4.5 0.6 1])
    title(['Simulated image with ', num2str(info.gridSize(2)), ' beams'],'FontSize',12)
    hold on;
    if (useMorePT)
        p2 = plot(out(2).dist,out(2).r,'r.--','LineWidth',2);
        p3 = plot(out(3).dist,out(3).r,'g.--','LineWidth',2);
        hold off;
        legend([p2,p1,p3],'Upper','Middle','Lower','Location','South')
    end
    hold off;
end

if p.N_MLA == 2
    texting = ', 2 MLA';
elseif p.N_MLA == 4
    texting = ', 4 MLA';
else
    texting = '';
end

figure;
plot(theta_all,out(1).r,'k.--','LineWidth',2)
title(['Simulated image with ', num2str(info.gridSize(2)), ' beams', texting],'FontSize',12)
xlabel('Distance from point target in reference frame [degree]','FontSize',12);
ylabel('Correlation coefficient','FontSize',12)
axis([-0.01 3.1 0.4 1])
hold on;
for i = 1:length(theta_receive_degree)
    if (theta_receive_degree(i) >= 0 && theta_receive_degree(i) <= 3.5)
        p1 = plot([theta_receive_degree(i) theta_receive_degree(i)],get(gca,'YLim'),'b--');
    end
end
for i = 1:length(theta_emit_degree)
    if (theta_emit_degree(i) >= 0 && theta_emit_degree(i) <= 3.5)
        p2 = plot([theta_emit_degree(i) theta_emit_degree(i)],get(gca,'YLim'),'r--');
    end
end
hold off;
if (p.N_MLA == 1)
    legend([p2],'Tx/Rx beams','Location','South')
else
    legend([p1,p2],'Rx beams','Tx beams','Location','South')
end

% Correlation coefficient, distance calculated by method 2
figure;
plot(theta_all2,out(1).r,'k.--','LineWidth',2)
title(['Simulated image with ', num2str(info.gridSize(2)), ' beams', texting],'FontSize',12)
xlabel('Distance from point target in reference frame [degree]','FontSize',12);
ylabel('Correlation coefficient','FontSize',12)
axis([-0.01 3.1 0.4 1])
hold on;
for i = 1:length(theta_receive_degree)
    if (theta_receive_degree(i) >= 0 && theta_receive_degree(i) <= 3.5)
        p1 = plot([theta_receive_degree(i) theta_receive_degree(i)],get(gca,'YLim'),'b--');
    end
end
for i = 1:length(theta_emit_degree)
    if (theta_emit_degree(i) >= 0 && theta_emit_degree(i) <= 3.5)
        p2 = plot([theta_emit_degree(i) theta_emit_degree(i)],get(gca,'YLim'),'r--');
    end
end
hold off;
if (p.N_MLA == 1)
    legend([p2],'Tx/Rx beams','Location','South')
else
    legend([p1,p2],'Rx beams','Tx beams','Location','South')
end

if (makeMovie)
    figure;
    for index = 1:length(sv)
        imagesc(abs(sv(index).compare(1).ROI_iq_new));
        M(index) = getframe;
    end
    movie2avi(M,'closePT_24IQ.avi','compression','None','fps',5)

    figure;
    for index = 1:length(sv)
        imagesc(sv(index).compare(1).data2);
        M2(index) = getframe;
    end
    movie2avi(M2,'PT_24IQ.avi','compression','None','fps',5)
end
