function [convAp, convAxis, apExtent] = calcConvAperture(p, txAperture, rxAperture)
               
        N = 1000;        
        axisWidth = 2*(txAperture + rxAperture); % Just chosen higher then the minimal...
        xAxis = linspace(-axisWidth/2,axisWidth/2,N);
        txVals = zeros(1,N);
        rxVals = zeros(1,N);
        txI = find(abs(xAxis) < txAperture/2);
        rxI = find(abs(xAxis) < rxAperture/2);
        
        % Apodization
        if(strcmpi(p.txApodization,'rect'))
            txVals(txI) = 1;
        elseif(strcmpi(p.txApodization,'hamming'))
            txVals(txI) = hamming(length(txI));;            
        elseif(strcmpi(p.txApodization,'cos(0.9)'))
            txVals(rxI) = offsetTukeyWin(length(txI), 0.1, 0.08);
        end
        if(strcmpi(p.rxApodization,'rect'))
            rxVals(rxI) = 1;
        elseif(strcmpi(p.rxApodization,'hamming'))
            rxVals(rxI) = hamming(length(rxI));
        elseif(strcmpi(p.rxApodization,'cos(0.9)'))
            rxVals(rxI) = offsetTukeyWin(length(rxI), 0.1, 0.08);
        end

        % two-way beam profile, bandlimited in k-space by the convolution
        % of the apodization functions on transmit and receive
        % Fourier av aperture -> 
        
        if(~p.harmonic)
            txrxConv = conv2(txVals,rxVals,'same');
            txrxConv = txrxConv / max(txrxConv);                        % normalisering
        else % If harmonic mode, then first autoconvolute txAperture
            txrxConv = conv2(conv2(txVals,txVals,'same'), rxVals,'same');
            txrxConv = txrxConv / max(txrxConv);
        end

        if(0) % Plot two-way aperture
            figure(1000); plot(xAxis, txrxConv); axis tight;
        end
        % Find aperture extent
        epsilon = 0;
        I = find(txrxConv(1:ceil(length(txrxConv)/2)) <= epsilon);      % finner hvor aperturen starter 
        apExtent = 2*abs(xAxis(I(end)));                                % hvos stor aperturen er
        convAxis = xAxis;            
        convAp = txrxConv;
        
%         if(p.plotTwowayAperture)
%             figure(1010);
%             clf;
%             hold on;
%             plot(xAxis,txVals,'k-');
%             plot(xAxis,rxVals,'k--');
%             plot(xAxis,txrxConv,'k-.');
%             hold off;
%             axis tight;
%             grid on; box on;
%             legend('TxAperture','RxAperture','Twoway aperture');
%         end            
end

    