function dispContactMap(data,setup)

%% Default setup
    p = struct();
    p.dispType = 'bar'; % ['plot','bar']
    p.figNo = 1000;
    p.title = 'Probe contact map';
    p.xlabel = 'Aperture axis [cm]';
    p.ylabel = 'Power [dB]';
    p.ylim = -1; % No limitation
    p.fontSizeSmall = 12;
    p.fontSizeLarge = 14;
    
    % Bar setup
    p.numBars = 10;
    p.barColor = [50 0 0];
    
%% Override with provided settings
    if(exist('setup'))
        fields = fieldnames(setup);
        for k=1:size(fields,1);
            if(isfield(p,fields{k}))
                p = setfield(p, fields{k}, getfield(setup,fields{k}));
            end
        end
    end
        
%% Display contact map
    apAxis = linspace(data.apAxis(1),data.apAxis(end),p.numBars-1);
    hfig = figure(p.figNo);
    clf;
    set(gca,'FontSize',p.fontSizeSmall);
    if(strcmp(p.dispType,'bar'))       
        I = round(linspace(1,length(data.contactMap),p.numBars));
        for k=1:length(I)-1,
           barMap(k) = mean(data.contactMap(I(k):I(k+1)-1));
        end
        hold on;
        % Plot spectrum
        hbar = bar(apAxis*100,barMap,1);
        set(hbar(1),'FaceColor',setup.color,'Edgecolor','k');
        if(p.ylim ~= -1)
            ylim(p.ylim);
        end
        box on;
        %axis tight;
        
        % Testing
        if(0 && isfield(data,'convAp'))
            convAp = 10*log10(data.convAp*max(data.latSpect) + eps);
            hApFull = plot(data.convAxis*100,convAp,'--'); 
        end
        if(1 && isfield(data,'x_mean'))
            EstConvAp = 10*log10(data.EstConvAp*max(data.latSpect) + eps);
            plot([data.x_mean data.x_mean]*100,get(gca,'YLim'),'g--'); 
            %plot([data.x_meanAcorr data.x_meanAcorr]*100,get(gca,'YLim'),'g--');  
            YBw = max(data.contactMap) - 10*log10(exp(3^2*0.5));
            data.x_bw = data.x_bw*3;                                                
            %plot([data.x_mean-data.x_bw/2, data.x_mean+data.x_bw/2]*100,[YBw YBw],'m');
            hApEst = plot((data.EstConvAxis+data.x_mean)*100,EstConvAp,'--b');
            %hApEst = plot((data.EstConvAxis+data.x_meanAcorr)*100,EstConvAp,'--b'); 

        end
        
        % Plot aperture size
        hAp = plot(100*[data.apDim data.apDim]/2,get(gca,'YLim'),'k--');      
        plot(-100*[data.apDim data.apDim]/2,get(gca,'YLim'),'k--');
        YLim = get(gca,'YLim');
        XLim = get(gca,'XLim');
        text(XLim(1)+abs(XLim(1))/30,YLim(2)-abs(YLim(2))/20,['Aperture: ' num2str(data.EstApFactor*100,'%.1f') '%'],'FontSize', p.fontSizeSmall);
        totRectWidth = abs(XLim(1))/2.5; totRectHeight = abs(YLim(2))/16;
        rectangle('Position',[XLim(1)+abs(XLim(1))/30, YLim(2)-abs(YLim(2))/7, totRectWidth, totRectHeight],'FaceColor','black');
        if(data.x_mean > 0)
            rectangle('Position',[XLim(1)+abs(XLim(1))/30+totRectWidth*(1-data.EstApFactor), YLim(2)-abs(YLim(2))/7, totRectWidth*(data.EstApFactor), totRectHeight],'FaceColor','white');
        else
             rectangle('Position',[XLim(1)+abs(XLim(1))/30, YLim(2)-abs(YLim(2))/7, totRectWidth*(data.EstApFactor), totRectHeight],'FaceColor','white');           
        end
        hold off;
        legend([hAp hApEst],'Aperture extents','Estimated aperture');
    elseif(strcmp(p.dispType,'plot'))
        plot(100*data.apAxis, data.contactMap);
        box on;
        axis tight;        
    end
   
    title(p.title);
    xlabel(p.xlabel);
    ylabel(p.ylabel);