function Fm=polyreg(N,P,dw,skipendpoints,AttenAtZero);
%------------------------------------------------------------------------
% Routine         : polyreg.m
% Description     :  Generate NxN filter matrix Fm for polynomial regression filter
%							 Fm=polyreg(N,P,dw,skipendpoints,AttenAtZero);
%							N = packet size (number of temporal samples)  N >= 2
%							P = max. polynomial order .  OBS:  -1<= P < N-1.  P=-1 gives Fm=identity matrix
%							dw [rad] = filter center frequency offset. if abs(dw)>0, an aditional zero is added at freq.=0
%							In this case P should be less than N-2
%							skipendpoints=1 removes first and last output sample in the filter output signal
%							default, skipendpoints=0
%							AttenAtZero is the attenuation at zero frequency in [dB]
%							If not spesified AttenAtZero= + inf.

% Language        : Matlab 4.2
% Written by      :   Hans Torp 29/2-96
% Version no.     : 1.1  second version
%							1.2 opprydning, virker naa ogsaa for P>6
%							1.3 skipendpoints inkludert 16/1 97 Hans Torp
%							1.4 AttenAtZero inkludert 10/3 97 Hans Torp
% Called by       : testcf
%------------------------------------------------------------------------
if nargin<3,dw=0;end;
if nargin<4,skipendpoints=0;end;
if nargin<5,AttenAtZero=  120;end;

if abs(dw)>0.0001, P=P+1; ,else dw=0;end;
if P> (N-2), disp('Filter order too large');return; end;

c=ones(P+1,1);
Nc=length(AttenAtZero);
for p=0:P,
    if p<Nc, c(p+1) = 1- 10^(-AttenAtZero(p+1)/20);end;
end;

Fm= zeros(N,N);

t=1:N;
if P>-1,
%form the polynomial basis vectors by Gramm-Schmith
base=zeros(P+1,N);
for p=0:P,
	b=t.^p;%polynom of order p
	if p>0, if abs(dw)>0, b=t.^(p-1).*exp(i*dw*t);end;end;%	polynom of order p-1, incl. mixing
	for k=0:p-1, %ortogonalization
			 bk=base(k+1,:);
			 b=b-(b*bk')*bk;
	end; 
	b=b/sqrt(b*b');%Normalization
	base(p+1,:)=b;
	Fm=Fm+ c(p+1)*b'*b;
end;%for p
end;%P>-1


Fm = eye(N,N) - Fm;

if skipendpoints, Fm=Fm(2:N-1,:);end;
nargout

if nargout<1, clutterfreqresp(Fm);end

function [f,H]=clutterfreqresp(Fm,Nf);
if nargin<2,Nf=256;end;
f=0:1/Nf:(1-1/Nf);f=f - 0.5;
Fmf=fft(Fm,Nf)';
H=mean(conj(Fmf).*Fmf);
H=abs(fftshift(H'))';
if nargout==0,
plot(f,10*log10(H));axis([-0.5 0.5 -100 0]);grid;
end;

